==> haskell-conduit-1.2.6.4-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.6.4
id: conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
key: condu_I58zpeV6KXSGprp2tu0S0i
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
    .
    @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://www.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-1.2.6.4
hs-libraries: HSconduit-1.2.6.4-I58zpeV6KXSGprp2tu0S0i
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.2.6.6-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.6.6
id: conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
key: condu_Fh2Qb49Eq0u64d6unodoFp
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
    .
    @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://www.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-1.2.6.6
hs-libraries: HSconduit-1.2.6.6-Fh2Qb49Eq0u64d6unodoFp
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
